bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 13. Aventiure
___________________________________________________ #### Aventivre wie chriemhilt mit ir man #### zer hochgecite fvr
###### 778 | ### Alle ir vnmvze | di laze wir nv sin ### vnde sagen wi vrowe criemhilt | vnt ovch ir magedin ### gegen rine fvren | von nibelvnge lant ### ni getrvgen moere | so manich riche gewant
###### 779 | ### vil der sovmschrine | man schiet zv den waegen ### do reit mit sinen vrivnden | sifrit der daegen ### vnd ovch div chvngeninne | dar si haeten vrevden wan ### sit wart ez in allen | ce grozem leide getan
###### 780 | ### da heime si do liezen | sifrides chindelin ### vnt svn criemhilde | daz mvs et also sin ### von ir hovereise | im erstvnt michel ser ### sin vater vnt sin mvter | gesach daz chindel nimmer mer
###### 781 | ### do reit ovch mit in dannen | der herre sigemunt ### sold er rehte wizzen | wi ez nach der stvnt ### cer hogecite ergienge | er hete ir niht gesehen ### im chvnde ce lieben vrivnden | nimmer leider geschehen
###### 782 | ### di boten man fvr sande | di div maere sageten dar ### do reit ovch in engegen | mit wunnechlicher shar ### vil der voten vrivnde | vnt der gvntheres man ### der wirt gegen sinen gesten | vil sere sich vlizen began
###### 783 | ### er gie zv prvnnhilt | da er di sitzen vant ### wi enpfie et ivch min swester | do ir chomet in min lant ### alsam sult ir enpfahen | daz sifrides wip ### daz tvn ich von schvlden gerne | holt ist ir min lip
###### 784 | ### do sprach der kvenich riche | si chvment morgen vrv ### welt ir si enpfahen | da griffet balde zv ### daz wir ir in der bverge | niht erbiten hie ### mir chomen in allen wilen | so rehte liebe geste nie
###### 785 | ### ir maegde vnt ir vrowen | hiez do sa cehant ### svehen gvtev chleider | di besten di man vant ### di ir ingesinde | vor gesten solden tragen ### daz taten si doch gerne | daz mach man lihte gesagen
###### 786 | ### ovch ilten in do dienen | di gvntheres man ### alle sine rechen | der wirt zv sich gewan ### do reit div kveneginne | vil herliche dan ### da wart vil michel grvezen | di liebe geste getan
###### 787 | ### mit wi getanen vrevden | man di geste enpfie ### si dvhte daz vrov criemhilt | vrovn prvnnhilde nie ### so rehte wol enpfienge | in bvergvnde lant ### di si e niht gesahen | den wart vil hoher mvot erchant
###### 788 | ### nv was ovch chomen sifrit | mit den sinen man ### man sach di helde wenden | wider vnde dan ### des veldes allenthalben | mit vngefvegen scharn ### dringen vnd stovben | chvnde da niemen bewarn
###### 789 | ### do der wirt des landes | sifride sach ### vnt ovch sigemvnde | wi minnechlich er do sprach ### nv sit mir groze willechomen | vnt al di vrivnde min ### der iwer hovereise | svl wir hohgemvte sin
###### 790 | ### nv lon iv got sprach sigemvnt | der ere gernde man ### sit daz ivch min svn sifrit | ce vrivnde gewan ### do rieten mine sinne | daz ich ivch solde saehen ### do sprach der chvnich gvnther | mir ist liebe daran geschehen
###### 791 | ### sifrit wart enpfangen | als im da wol gezam ### mit vil grozen eren | was im da niemen gram ### des half mit grozen zvehten | giselher vnt gernot ### ich waene man ez gesten | noch nie so gvetlich erbot
###### 792 | ### do nahten zv einander | der zweir kvenege wip ### da wart vil satel laere | manich schoener vrowen lip ### wart von helde handen | erhaben vf daz gras ### di vrowen gerne dienten | waz der vmmvezegen was
###### 793 | ### do giengen zv einander | div minnechlichen wip ### des was in grozen vrevden | vil maniges ritters lip ### daz ir beider grvezen | so schone wart getan ### do sach man vil der rechen | bi ir ivnchvrowen stan
###### 794 | ### daz herliche gesinde | daz vie sich bi der hant ### in zvehte groze nigen | des man vil da vant ### vnd chvessen minnechlichen | von vrowen wolgetan ### daz was liep ce saehene | gvnthers vnd sifrides man
###### 795 | ### si ne bitten da niht langer | si ritten zv der stat ### der wirt daz sinen gesten | wol erceigen bat ### daz man si gerne saehe | in bvrgvnden lant ### vil manigen pvneiz richen | man vor den ivnchvrowen vant
###### 796 | ### vzer tronege hagene | vnt ovch ortwin ### da si gewaldech waeren | daz taten si wol schin ### swaz si gebieten wolden | daz torste man niht lan ### von in wart michel dienest | den lieben gesten getan
###### 797 | ### vil schilde hort man hellen | da ce dem pvergetor ### von stichen vnd von stoezen | lange habt dervor ### der wirt mit sinen gesten | e si chomen drin ### ia giench in div stvnde | mit grozer chverzwile hin
###### 798 | ### fver den palas richen | mit vrowen si do ritten ### manegen pfellel spaehen | gvt vnd wol gesniten ### sach man vber saetel | den vrowen wolgetan ### allenthalben hangen | do chomen gvntheres man
###### 799 | ### di geste hiez man fveren | balde an ir gemach ### vnder wilen blicken | man prvnnhilde sach ### aan vrovn criemhilde | div schoene was genvch ### ir varwe gegen dem golde | den glanz vil herlichen trvch
###### 800 | ### allenthalben schallen | ce wormez in der stat ### horte manz gesinde | gvnther do bat ### danchwarten sinen marshalch | daz ir solde pflegen ### do begond er daz gesinde | harte gvetliche legen
###### 801 | ### darvze vnt ovch darinne | spisen man si lie ### ia wart vremder geste | baz gepflegen nie ### alles des si gerten | des was man in bereit ### der chvenech der was so riche | daz da niemen niht wart verseit
###### 802 | ### man diente in vrivntliche | vnd an allen haz ### der wirt do ce tissche | mit sinen gesten saz ### man bat sifride sitzen | als er het e getan ### do gi mit im ce sedele | vil manich waetlicher man
###### 803 | ### wol zwelf hvndert recken | an dem ringe sin ### da ce tissche sazen | prvnnhilt die chvnegin ### gedaht daz eigenholde | niht richer chvnde wesin ### si was im noch so waege | daz si in gerne lie genaesin
###### 804 | ### an einem abende | da der chvenech saz ### vil der richen chleider | wart von wine naz ### da si schenchen solden | zv den tisschen gan ### da wart vil voller dienest | mit grozem vlize getan
###### 805 | ### so man ce hohziten | lange hat gepflegen ### vrowen vnt maegde | di hiez man schone legen ### von swannen si dar chomen | der wirt in willen trvch ### mit gvtlichen eren | man gap in allen genvch
###### 806 | ### do div naht het ende | vnt der tach ershein ### vz den sovmshrinen | vil manich edelstein ### erlvht in gvter waete | di rvorte vrowen hant ### do wart dar fver gesvchet | vil manich herlich gewant
###### 807 | ### e daz vol ertagete | do chomen fver den sal ### vil ritter vnde chnehte | do hvp sich aber der shal ### vor einer vrvemesse | di man dem chvenige sanch ### da ritten ivnge helde | daz sin der chvenech sagete danch
###### 808 | ### vil crepfteliche lvte | manich pvsvn erdoz ### von trvmben vnt von floyten | wart der shal so groz ### daz wormez div vil wite | darnach lvt ershal ### di hohgemvten helde | ce rossen chomen veberal
###### 809 | ### do hvp sich in dem lande | vil harte hohe ein spil ### von manigem gvtem rechen | der sah man da vil ### den ir tvmbiv herce | gaben hohen mvt ### da sah man vnder shilde | vil manigen cieren ritter gvt
###### 810 | ### in div venster sazen | div herlichiv wip ### vnd vil der schoenen maegede | gecieret was ir lip ### si sahen chverzewile | von manigem chvenem man ### der wirt mit sinen vrivnden | selbe riten began
###### 811 | ### svs vertriben si di wile | div dvhte niht lanch ### man horte da cem tvome | maniger gloken clanch ### do chomen in di moere | di vrowen ritten dan ### den edelen chveneginnen | den volgete manech chvene man
###### 812 | ### si stvnden vor dem mvenster | nider vf daz gras ### prvnnhilt ir gesten | dannoch vil waege was ### si giengen vnder crone | in daz mvenster wit ### div liebe wart sit gesheiden | daz frvmte grozlicher nit
###### 813 | ### do si gehorten messe | si fvren wider dan ### mit vil manigen eren | man sach sider gan ### ce tissche vroliche | ir vrevde nie gelach ### da cer hohgecite | vnz an den einlefften tach

<<< Übersicht <<< vorige Seite nächste Seite >>>